==> cloudfront-1.60.0-sources.jar: software/amazon/awscdk/services/cloudfront/CfnStreamingDistributionProps.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Properties for defining a `AWS::CloudFront::StreamingDistribution`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudfront-streamingdistribution.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.529Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.CfnStreamingDistributionProps")
@software.amazon.jsii.Jsii.Proxy(CfnStreamingDistributionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnStreamingDistributionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudFront::StreamingDistribution.StreamingDistributionConfig`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudfront-streamingdistribution.html#cfn-cloudfront-streamingdistribution-streamingdistributionconfig
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getStreamingDistributionConfig();

    /**
     * `AWS::CloudFront::StreamingDistribution.Tags`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudfront-streamingdistribution.html#cfn-cloudfront-streamingdistribution-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnStreamingDistributionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnStreamingDistributionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnStreamingDistributionProps> {
        private java.lang.Object streamingDistributionConfig;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnStreamingDistributionProps#getStreamingDistributionConfig}
         * @param streamingDistributionConfig `AWS::CloudFront::StreamingDistribution.StreamingDistributionConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder streamingDistributionConfig(software.amazon.awscdk.core.IResolvable streamingDistributionConfig) {
            this.streamingDistributionConfig = streamingDistributionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnStreamingDistributionProps#getStreamingDistributionConfig}
         * @param streamingDistributionConfig `AWS::CloudFront::StreamingDistribution.StreamingDistributionConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder streamingDistributionConfig(software.amazon.awscdk.services.cloudfront.CfnStreamingDistribution.StreamingDistributionConfigProperty streamingDistributionConfig) {
            this.streamingDistributionConfig = streamingDistributionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnStreamingDistributionProps#getTags}
         * @param tags `AWS::CloudFront::StreamingDistribution.Tags`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnStreamingDistributionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnStreamingDistributionProps build() {
            return new Jsii$Proxy(streamingDistributionConfig, tags);
        }
    }

    /**
     * An implementation for {@link CfnStreamingDistributionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnStreamingDistributionProps {
        private final java.lang.Object streamingDistributionConfig;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.streamingDistributionConfig = this.jsiiGet("streamingDistributionConfig", java.lang.Object.class);
            this.tags = this.jsiiGet("tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object streamingDistributionConfig, final java.util.List<software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.streamingDistributionConfig = java.util.Objects.requireNonNull(streamingDistributionConfig, "streamingDistributionConfig is required");
            this.tags = java.util.Objects.requireNonNull(tags, "tags is required");
        }

        @Override
        public java.lang.Object getStreamingDistributionConfig() {
            return this.streamingDistributionConfig;
        }

        @Override
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("streamingDistributionConfig", om.valueToTree(this.getStreamingDistributionConfig()));
            data.set("tags", om.valueToTree(this.getTags()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.CfnStreamingDistributionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnStreamingDistributionProps.Jsii$Proxy that = (CfnStreamingDistributionProps.Jsii$Proxy) o;

            if (!streamingDistributionConfig.equals(that.streamingDistributionConfig)) return false;
            return this.tags.equals(that.tags);
        }

        @Override
        public int hashCode() {
            int result = this.streamingDistributionConfig.hashCode();
            result = 31 * result + (this.tags.hashCode());
            return result;
        }
    }
}

==> cloudfront-1.93.0-sources.jar: software/amazon/awscdk/services/cloudfront/CfnStreamingDistributionProps.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Properties for defining a `AWS::CloudFront::StreamingDistribution`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.410Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.CfnStreamingDistributionProps")
@software.amazon.jsii.Jsii.Proxy(CfnStreamingDistributionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnStreamingDistributionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudFront::StreamingDistribution.StreamingDistributionConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getStreamingDistributionConfig();

    /**
     * `AWS::CloudFront::StreamingDistribution.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnStreamingDistributionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnStreamingDistributionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnStreamingDistributionProps> {
        private java.lang.Object streamingDistributionConfig;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnStreamingDistributionProps#getStreamingDistributionConfig}
         * @param streamingDistributionConfig `AWS::CloudFront::StreamingDistribution.StreamingDistributionConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder streamingDistributionConfig(software.amazon.awscdk.core.IResolvable streamingDistributionConfig) {
            this.streamingDistributionConfig = streamingDistributionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnStreamingDistributionProps#getStreamingDistributionConfig}
         * @param streamingDistributionConfig `AWS::CloudFront::StreamingDistribution.StreamingDistributionConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder streamingDistributionConfig(software.amazon.awscdk.services.cloudfront.CfnStreamingDistribution.StreamingDistributionConfigProperty streamingDistributionConfig) {
            this.streamingDistributionConfig = streamingDistributionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnStreamingDistributionProps#getTags}
         * @param tags `AWS::CloudFront::StreamingDistribution.Tags`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnStreamingDistributionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnStreamingDistributionProps build() {
            return new Jsii$Proxy(streamingDistributionConfig, tags);
        }
    }

    /**
     * An implementation for {@link CfnStreamingDistributionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnStreamingDistributionProps {
        private final java.lang.Object streamingDistributionConfig;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.streamingDistributionConfig = software.amazon.jsii.Kernel.get(this, "streamingDistributionConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.Object streamingDistributionConfig, final java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.streamingDistributionConfig = java.util.Objects.requireNonNull(streamingDistributionConfig, "streamingDistributionConfig is required");
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)java.util.Objects.requireNonNull(tags, "tags is required");
        }

        @Override
        public final java.lang.Object getStreamingDistributionConfig() {
            return this.streamingDistributionConfig;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("streamingDistributionConfig", om.valueToTree(this.getStreamingDistributionConfig()));
            data.set("tags", om.valueToTree(this.getTags()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.CfnStreamingDistributionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnStreamingDistributionProps.Jsii$Proxy that = (CfnStreamingDistributionProps.Jsii$Proxy) o;

            if (!streamingDistributionConfig.equals(that.streamingDistributionConfig)) return false;
            return this.tags.equals(that.tags);
        }

        @Override
        public final int hashCode() {
            int result = this.streamingDistributionConfig.hashCode();
            result = 31 * result + (this.tags.hashCode());
            return result;
        }
    }
}
